@@ -3,7 +3,7 @@ BEGIN {
   $Bread::Board::LifeCycle::Request::AUTHORITY = 'cpan:STEVAN';
 }
 {
-  $Bread::Board::LifeCycle::Request::VERSION = '0.11';
+  $Bread::Board::LifeCycle::Request::VERSION = '0.12';
 }
 use Moose::Role;
 use namespace::autoclean;
@@ -26,7 +26,7 @@ Bread::Board::LifeCycle::Request - lifecycle for request-scoped services
 
 =head1 VERSION
 
-version 0.11
+version 0.12
 
 =head1 SYNOPSIS
 
@@ -56,11 +56,11 @@ the request is finished.
 
 =item *
 
-Stevan Little <stevan.little at iinteractive.com>
+Stevan Little <stevan.little@iinteractive.com>
 
 =item *
 
-Jesse Luehrs <doy at cpan dot org>
+Jesse Luehrs <doy@tozt.net>
 
 =back
 
