@@ -3,7 +3,7 @@ BEGIN {
   $OX::Role::AUTHORITY = 'cpan:STEVAN';
 }
 {
-  $OX::Role::VERSION = '0.11';
+  $OX::Role::VERSION = '0.12';
 }
 use Moose::Exporter;
 use 5.010;
@@ -120,7 +120,7 @@ OX::Role - declare roles for your OX applications
 
 =head1 VERSION
 
-version 0.11
+version 0.12
 
 =head1 SYNOPSIS
 
@@ -331,11 +331,11 @@ option to L<Plack::Middleware::ErrorDocument>.
 
 =item *
 
-Stevan Little <stevan.little at iinteractive.com>
+Stevan Little <stevan.little@iinteractive.com>
 
 =item *
 
-Jesse Luehrs <doy at cpan dot org>
+Jesse Luehrs <doy@tozt.net>
 
 =back
 
