@@ -3,7 +3,7 @@ BEGIN {
   $OX::RouteBuilder::ControllerAction::AUTHORITY = 'cpan:STEVAN';
 }
 {
-  $OX::RouteBuilder::ControllerAction::VERSION = '0.11';
+  $OX::RouteBuilder::ControllerAction::VERSION = '0.12';
 }
 use Moose;
 use namespace::autoclean;
@@ -88,7 +88,7 @@ OX::RouteBuilder::ControllerAction - OX::RouteBuilder which routes to an action
 
 =head1 VERSION
 
-version 0.11
+version 0.12
 
 =head1 SYNOPSIS
 
@@ -124,11 +124,11 @@ the route, as well as C<name> (which will be set to C<"$controller.$action">.
 
 =item *
 
-Stevan Little <stevan.little at iinteractive.com>
+Stevan Little <stevan.little@iinteractive.com>
 
 =item *
 
-Jesse Luehrs <doy at cpan dot org>
+Jesse Luehrs <doy@tozt.net>
 
 =back
 
